@@ -223,7 +223,7 @@ $messages = array(
 'errorpagetitle'    => 'Йоҥылыш',
 'returnto'          => '$1 деке пӧртылаш.',
 'tagline'           => '{{SITENAME}} гыч',
-'help'              => 'Полшык',
+'help'              => 'Полшыш',
 'search'            => 'Кычалмаш',
 'searchbutton'      => 'Кычалаш',
 'go'                => 'Куснаш',
@@ -255,7 +255,7 @@ $messages = array(
 'userpage'          => 'Пайдаланышын лаштыкым ончалаш',
 'imagepage'         => 'Файлын лаштыкым ончалаш',
 'templatepage'      => 'Ямдылыкын лаштыкым ончалаш',
-'viewhelppage'      => 'Полшык лаштыкым ончалаш',
+'viewhelppage'      => 'Полыш лаштыкым ончалаш',
 'categorypage'      => 'Категорийын лаштыкым ончалаш',
 'viewtalkpage'      => 'Ончалаш каҥашымашым',
 'otherlanguages'    => 'Вес йылме дене',
@@ -354,17 +354,17 @@ $messages = array(
 'yourpasswordagain'       => 'Шолыпмутым угыч пуртымаш:',
 'remembermypassword'      => 'Тиде компьютерыште мыйым шарнаш (эн шуко $1 {{PLURAL:$1|кечылан|кечылан}})',
 'yourdomainname'          => 'Тендан домен:',
-'login'                   => 'Шке денет палымым ыште',
+'login'                   => 'Шке денет палдаре',
 'nav-login-createaccount' => 'Пураш/Регистрацийым эрте',
-'loginprompt'             => '{{SITENAME}} тый денет палыме лиймашлан, cookies чӱкталтын улшаш.',
-'userlogin'               => 'Шке денет палымым ыште/Регистрацийым эрте',
+'loginprompt'             => '{{SITENAME}} шке денет палдарыме деч ончыч компьютерыштет «cookies»-ым чӱктыман.',
+'userlogin'               => 'Пураш/Регистрацийым эрташ',
 'logout'                  => 'Лекташ',
 'userlogout'              => 'Лекташ',
 'nologin'                 => "Тый регистрацийым эше эртен отыл? '''$1'''.",
 'nologinlink'             => 'Регистрацийым эрте',
 'createaccount'           => 'Регистрацийым эрте',
 'gotaccount'              => "Тый регистрацийым эртенат? '''$1'''.",
-'gotaccountlink'          => 'Шке денет палымым ыште',
+'gotaccountlink'          => 'Шке денет палдаре',
 'userlogin-resetlink'     => 'Лӱмдам але шолыпмутдам монденда?',
 'createaccountmail'       => 'e-mail дене',
 'nosuchuser'              => '"$1" лӱман пайдаланыше уке.
@@ -998,7 +998,7 @@ $messages = array(
 'tooltip-pt-preferences'          => 'Мыйын келыштарымашем',
 'tooltip-pt-watchlist'            => 'Мыйын эскерыме лаштык-влак лӱмер',
 'tooltip-pt-mycontris'            => 'Тыйын пашатым эскерыме лаштык',
-'tooltip-pt-login'                => 'Шке денет палымым ыштет гын сайрак лиеш; такшым тидым ыштыдеат кертат.',
+'tooltip-pt-login'                => 'Тыште регистрацийым эртен кертат. Регистраций деч поснаат пашам ышташ лиеш.',
 'tooltip-pt-logout'               => 'Системе гыч лекташ',
 'tooltip-ca-talk'                 => 'Лаштыкыште возымым каҥашаш',
 'tooltip-ca-edit'                 => 'Тый тиде лаштыкым тӧрлатен кертат. Лаштыкым аралыме деч ончыч тудым тергаш ит мондо.',
@@ -1021,7 +1021,7 @@ $messages = array(
 'tooltip-n-currentevents'         => 'Мо лийме нерген нерген пытартыш увер',
 'tooltip-n-recentchanges'         => 'Пытартыш вашталтымаш лӱмер',
 'tooltip-n-randompage'            => 'Лаштыкым чокым ойыраш',
-'tooltip-n-help'                  => 'Википедийым кучылтмо да тӧрлатыме шотышто полшык.',
+'tooltip-n-help'                  => 'Википедийым кучылтмо да тӧрлатыме шотышто полыш.',
 'tooltip-t-whatlinkshere'         => 'Тышке кондышо лаштык-влакын лӱмерышт',
 'tooltip-t-recentchangeslinked'   => 'Тиде лаштык дене кылдалтше пытартыш тӧрлатымаш-влак',
 'tooltip-feed-rss'                => 'Тиде лаштыклан RSS-кыл',
@@ -1095,7 +1095,7 @@ $messages = array(
 
 # External editor support
 'edit-externally'      => 'Файлым ӧрдыж программыште тӧрлаташ',
-'edit-externally-help' => '(Сайрак палашлан ончал [//www.mediawiki.org/wiki/Manual:External_editors шындымаш нерген туныктымашым])',
+'edit-externally-help' => '(Сайрак палашлан ончал [https://www.mediawiki.org/wiki/Manual:External_editors шындымаш нерген туныктымашым])',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'чыла',
